@@ -12,7 +12,7 @@ module Assistant.WebApp.Configurators.Local where
 import Assistant.WebApp.Common
 import Assistant.WebApp.OtherRepos
 import Assistant.WebApp.Gpg
-import Assistant.MakeRemote
+import Assistant.WebApp.MakeRemote
 import Assistant.Sync
 import Init
 import qualified Git
