@@ -13,7 +13,7 @@ module Assistant.WebApp.Configurators.Ssh where
 import Assistant.WebApp.Common
 import Assistant.WebApp.Gpg
 import Assistant.Ssh
-import Assistant.MakeRemote
+import Assistant.WebApp.MakeRemote
 import Logs.Remote
 import Remote
 import Types.StandardGroups
@@ -21,7 +21,6 @@ import Utility.UserInfo
 import Utility.Gpg
 import Types.Remote (RemoteConfig)
 import Git.Remote
-import Assistant.WebApp.Utility
 import qualified Remote.GCrypt as GCrypt
 import Annex.UUID
 import Logs.UUID
@@ -390,7 +389,7 @@ prepSsh' newgcrypt origsshdata sshdata keypair a = sshSetup
 	remoteCommand = shellWrap $ intercalate "&&" $ catMaybes
 		[ Just $ "mkdir -p " ++ shellEscape remotedir
 		, Just $ "cd " ++ shellEscape remotedir
-		, if rsynconly then Nothing else Just "if [ ! -d .git ]; then git init --bare --shared; fi"
+		, if rsynconly then Nothing else Just "if [ ! -d .git ]; then git init --bare --shared && git config receive.denyNonFastforwards false; fi"
 		, if rsynconly || newgcrypt then Nothing else Just "git annex init"
 		, if needsPubKey origsshdata
 			then addAuthorizedKeysCommand (hasCapability origsshdata GitAnnexShellCapable) remotedir . sshPubKey <$> keypair
