@@ -53,5 +53,11 @@ buildFlags = filter (not . null)
 #endif
 #ifdef WITH_QUVI
 	, "Quvi"
+#endif
+#ifdef WITH_TDFA
+	, "TDFA"
+#endif
+#ifdef WITH_CRYPTOHASH
+	, "CryptoHash"
 #endif
 	]
